@@ -65,8 +65,8 @@ void CUpDownClient::DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect
 	s_StatusBar.SetWidth(rect.width- rect.x);
 	s_StatusBar.Fill(crNeither);
 	// Barry - was only showing one part from client, even when reserved bits from 2 parts
-	CString gettingParts;
-	ShowDownloadingParts(&gettingParts);
+	wxString gettingParts;
+	ShowDownloadingParts(gettingParts);
 	if (!onlygreyrect&& reqfile&& m_abyPartStatus) {
 		for (uint32 i = 0;i != m_nPartCount;i++) {
 			if (m_abyPartStatus[i]) {
@@ -146,47 +146,50 @@ bool CUpDownClient::IsSourceRequestAllowed() {
 }
 
 void CUpDownClient::SendFileRequest() {
-	if(!reqfile) return;
-	AddAskedCountDown();
-	CSafeMemFile dataFileReq(32);
-	dataFileReq.Write(reqfile->GetFileHash(), 16);
-	Packet* packet = new Packet(&dataFileReq);
-	packet->opcode=OP_FILEREQUEST;
-	theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
-	socket->SendPacket(packet, true);
- /*
- 26-Jul-2003: removed requesting the file status for files <= PARTSIZE
- for better compatibility with ed2k protocol (eDonkeyHybrid).  If the
- remote client answers the OP_FILEREQUEST with OP_FILEREQANSWER the file
- is shared by the remote client.  If we know that the file is shared, we
- know also that the file is complete and don't need to request the file
- status.
-    */
+	if(reqfile) {
+		AddAskedCountDown();
+		CSafeMemFile dataFileReq(32);
+		dataFileReq.Write(reqfile->GetFileHash(), 16);
 #if defined(__DEBUG__)
-	printf("CUpDownClient::SendFileRequest OP_FILEREQUEST\n");
+        printf("SendFileRequest\n");
 #endif
-	CSafeMemFile dataSetReqFileID(16);
-	dataSetReqFileID.Write(reqfile->GetFileHash(), 16);
-	packet = new Packet(&dataSetReqFileID);
-	packet->opcode = OP_SETREQFILEID;
-	theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
-	socket->SendPacket(packet, true);
+		if(GetExtendedRequestsVersion() >0) {
+			reqfile->WritePartStatus(&dataFileReq);
+		}
+		if(GetExtendedRequestsVersion() >1) {
+			//zegzav:completesrc (add):
+			//reqfile->WriteCompleteSourcesCount(&dataFileReq);
+		}
+		Packet* packet = new Packet(&dataFileReq);
+		packet->opcode=OP_FILEREQUEST;
+		theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
+		socket->SendPacket(packet, true);
 #if defined(__DEBUG__)
-	printf("CUpDownClient::SendFileRequest OP_SETREQFILEID\n");
+		printf("CUpDownClient::SendFileRequest OP_FILEREQUEST\n");
 #endif
-	if (IsEmuleClient()) {
-		SetRemoteQueueFull(true);
-	}
-	SetRemoteQueueRank(0);
-	if (IsSourceRequestAllowed()) {
-		reqfile->SetLastAnsweredTimeTimeout();
-		Packet* packet = new Packet(OP_REQUESTSOURCES,16,OP_EMULEPROT);
-		md4cpy(packet->pBuffer, reqfile->GetFileHash());
-		theApp.uploadqueue->AddUpDataOverheadSourceExchange(packet->size);
-		socket->SendPacket(packet,true,true);
+		CSafeMemFile dataSetReqFileID(16);
+		dataSetReqFileID.Write(reqfile->GetFileHash(), 16);
+		packet = new Packet(&dataSetReqFileID);
+		packet->opcode = OP_SETREQFILEID;
+		theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
+		socket->SendPacket(packet, true);
 #if defined(__DEBUG__)
-		printf("CUpDownClient::SendFileRequest OP_REQUESTSOURCES\n");
+		printf("CUpDownClient::SendFileRequest OP_SETREQFILEID\n");
 #endif
+		if (IsEmuleClient()) {
+			SetRemoteQueueFull(true);
+		}
+		SetRemoteQueueRank(0);
+		if (IsSourceRequestAllowed()) {
+			reqfile->SetLastAnsweredTimeTimeout();
+			Packet* packet = new Packet(OP_REQUESTSOURCES,16,OP_EMULEPROT);
+			md4cpy(packet->pBuffer, reqfile->GetFileHash());
+			theApp.uploadqueue->AddUpDataOverheadSourceExchange(packet->size);
+			socket->SendPacket(packet,true,true);
+#if defined(__DEBUG__)
+			printf("CUpDownClient::SendFileRequest OP_REQUESTSOURCES\n");
+#endif
+		}
 	}
 }
 
@@ -360,8 +363,7 @@ void CUpDownClient::ProcessHashSet(unsigned char* packet,uint32 size) {
 
 void CUpDownClient::SendBlockRequests() {
 	m_dwLastBlockReceived = ::GetTickCount();
-	if (!reqfile)
-	return;
+	if (reqfile) {
 	if (m_DownloadBlocks_list.IsEmpty()) {
 		// Barry - instead of getting 3, just get how many is needed
 		uint16 count = 3- m_PendingBlocks_list.GetCount();
@@ -399,8 +401,7 @@ void CUpDownClient::SendBlockRequests() {
 			block = m_PendingBlocks_list.GetAt(pos)->block;
 			m_PendingBlocks_list.GetNext(pos);
 			data->Write(&block->StartOffset,4);
-		}
-		else
+		} else
 			data->Write(&null,4);
 	}
 	pos = m_PendingBlocks_list.GetHeadPosition();
@@ -410,36 +411,15 @@ void CUpDownClient::SendBlockRequests() {
 			m_PendingBlocks_list.GetNext(pos);
 			uint32 endpos = block->EndOffset+1;
 			data->Write(&endpos,4);
-		}
-		else
+		} else
 			data->Write(&null,4);
 	}
 	delete data;
 	theApp.uploadqueue->AddUpDataOverheadFileRequest(packet->size);
 	socket->SendPacket(packet,true,true);
+	}
 }
 
- /* Barry - Originally this only wrote to disk when a full 180k block
- had been received from a client, and only asked for data in
- 180k blocks.
- This meant that on average 90k was lost for every connection
- to a client data source. That is a lot of wasted data.
- To reduce the lost data, packets are now written to a buffer
- and flushed to disk regularly regardless of size downloaded.
- This includes compressed packets.
- Data is also requested only where gaps are, not in 180k blocks.
- The requests will still not exceed 180k, but may be smaller to
- fill a gap.
-    */
-
-
-
-
-
-
-
-
-
 void CUpDownClient::ProcessBlockPacket(char *packet, uint32 size, bool packed) {
 	// Ignore if no data required
 	if (!(GetDownloadState() == DS_DOWNLOADING|| GetDownloadState() == DS_NONEEDEDPARTS))
@@ -717,22 +697,21 @@ void CUpDownClient::UDPReaskForDownload() {
 }
 
 // Barry - Sets string to show parts downloading, eg NNNYNNNNYYNYN
-void CUpDownClient::ShowDownloadingParts(CString *partsYN) {
+void CUpDownClient::ShowDownloadingParts(wxString &partsYN) {
 	Requested_Block_Struct *cur_block;
-	int x;
-	// Initialise to all N's
-	char *n = new char[m_nPartCount+1];
-	//_strnset(n, 'N', m_nPartCount);
-	memset(n,'N',m_nPartCount);
-	n[m_nPartCount] = 0;
-	//partsYN->SetString(n, m_nPartCount);
-	//partsYN=n;
-	*partsYN<<n;
-	delete [] n;
+	unsigned int x;
+	partsYN.Alloc(m_nPartCount+1);
+	for(x=0;x<=m_nPartCount;x++) partsYN.SetChar(x,'N');
 	for (POSITION pos = m_PendingBlocks_list.GetHeadPosition(); pos != 0; m_PendingBlocks_list.GetNext(pos)) {
 		cur_block = m_PendingBlocks_list.GetAt(pos)->block;
 		x = (cur_block->StartOffset / PARTSIZE);
-		partsYN->SetChar(x, 'Y');
+		if(x<=partsYN.Len()) {
+			partsYN.SetChar(x, 'Y');
+		} else {
+#if defined(__DEBUG__)
+			printf("CUpDownClient::ShowDownloadingParts x(%ld) > partsYN.Len()(%ld) pc=%ld\n", x,partsYN.Len(),m_nPartCount);
+#endif
+		}
 	}
 }
 
@@ -749,6 +728,7 @@ void CUpDownClient::UpdateDisplayedInfo(bool force) {
 
 
 
+
 void CUpDownClient::SwapToThisFile(CPartFile* file) {
 	// Get the position of the file in other requests' list
 	POSITION position = this->m_OtherRequests_list.Find(file);
@@ -856,6 +836,7 @@ void CUpDownClient::SwapToThisFile(CPartFile* file) {
 
 
 
+
 bool CUpDownClient::SwapToAnotherFile() {
 	if (this->GetDownloadState() == DS_DOWNLOADING)
 	return false;
@@ -922,6 +903,7 @@ bool CUpDownClient::SwapToAnotherFile() {
 
 
 
+
 void CUpDownClient::SetDownloadFile(CPartFile *part) {
 	delete[] m_abyPartStatus;
 	m_abyPartStatus = NULL;
