@@ -159,7 +159,6 @@ void CEMSocket::ClearQueues() {
 
 void CEMSocket::OnClose(int nErrorCode) {
 	byConnected = ES_DISCONNECTED;
-	//CAsyncSocket::OnClose(nErrorCode);
 	ClearQueues();
 };
 
@@ -265,15 +264,13 @@ void CEMSocket::OnReceive(int nErrorCode) {
 			pendingPacketSize = 0;
 		}
 		// Bytes ready to be copied into packet's internal buffer
-		//wxASSERT(rptr <= rend);
-		uint32 toCopy = ((pendingPacket->size- pendingPacketSize) < (uint32) (rend- rptr)) ?
+		uint32 toCopy = ((pendingPacket->size- pendingPacketSize) <= (uint32) (rend- rptr)) ?
 		(pendingPacket->size- pendingPacketSize) : (uint32) (rend- rptr);
 		// Copy Bytes from Global buffer to packet's internal buffer
 		memcpy(&pendingPacket->pBuffer[pendingPacketSize], rptr, toCopy);
 		pendingPacketSize+= toCopy;
 		rptr+= toCopy;
 		// Check if packet is complet
-		//wxASSERT(pendingPacket->size >= pendingPacketSize);
 		if(pendingPacket->size == pendingPacketSize) {
 			// Process packet
 			PacketReceived(pendingPacket);
@@ -283,8 +280,6 @@ void CEMSocket::OnReceive(int nErrorCode) {
 		}
 	}
 	// Finally, if there is any data left over, save it for next time
-	//	wxASSERT(rptr <= rend);
-	//	wxASSERT(rend - rptr < PACKET_HEADER_SIZE);
 	if(rptr != rend) {
 		// Keep the partial head
 		pendingHeaderSize = rend- rptr;
@@ -292,85 +287,6 @@ void CEMSocket::OnReceive(int nErrorCode) {
 	}
 }
 
-
- /*
- void CEMSocket::OnReceive(int nErrorCode)
- {
- // the 2 meg size was taken from another place
- static char GlobalReadBuffer[MAX_SIZE];
- if (nErrorCode){
- OnError(nErrorCode);
- return;
- }
- if (byConnected == ES_DISCONNECTED) {
- return;
- } else {
- byConnected = ES_CONNECTED;
- }
- uint32 readMax = sizeof(GlobalReadBuffer) - readbuf_size;
- // Buffer overflow
- if (readMax == 0) {
- delete readbuf;
- readbuf = NULL;
- readbuf_size = 0;
- OnError(ERR_TOOBIG);
- return;
- }
- if (limitenabled && readMax > downloadlimit) {
- readMax = downloadlimit;
- }
- // We attempt to read up to 2 megs at a time (minus whatever is in our internal read buffer)
- Read(GlobalReadBuffer+readbuf_size,readMax);
- uint32 ret=LastCount();
- if (Error() || ret == 0) {
- return;
- }
- if (limitenabled) {
- downloadlimit -= ret;
- }
- // Copy over our temporary read buffer into the global read buffer for processing
- if (readbuf) {
- memcpy(GlobalReadBuffer, readbuf, readbuf_size);
- ret += readbuf_size;
- delete[] readbuf;
- readbuf = NULL;
- readbuf_size = 0;
- }
- char *rptr = GlobalReadBuffer;
- char *rend = GlobalReadBuffer + ret;
- // Loop, processing packets until we run out of them
- while (rend - rptr >= 6) {
- Packet *packet = new Packet(rptr);
- rptr += 6;
- if (packet->size > sizeof(GlobalReadBuffer)) {
- delete packet;
- OnError(ERR_TOOBIG);
- return;
- }
- if (packet->size > rend - rptr) {
- rptr -= 6;
- delete packet;
- break;
- }
- char *packetBuffer = new char[packet->size + 1];
- memcpy(packetBuffer, rptr, packet->size);
- rptr += packet->size;
- packet->pBuffer = packetBuffer;
- PacketReceived(packet);
- delete packet;
- }
- // Finally, if there is any data left over, save it for next time
- //wxASSERT(rptr <= rend);
- if (rptr != rend) {
- readbuf_size = rend - rptr;
- readbuf = new char[readbuf_size];
- memcpy(readbuf, rptr, readbuf_size);
- }
- }
-    */
-
-
-
 void CEMSocket::SetDownloadLimit(uint32 limit) {
 	limitenabled = true;
 	downloadlimit = limit;
