@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -85,6 +89,7 @@ public:
 	uint32*	GetFileTypePtr()		{return &m_iFileType;}
 	uint32	GetFileType()			{return m_iFileType;}
 	void	SetFileName(char* NewName); // Added by Tarod [Juanjo]
+	void SetFileSize(uint32 nFileSize) { m_nFileSize = nFileSize; }
 	
 protected:
 	char*	m_pszFileName;
@@ -161,14 +166,23 @@ private:
 	void	CreateHashFromInput(FILE* file,CFile* file2, int Length, uchar* Output, uchar* = 0);
 	bool	m_bCommentLoaded;
 	uint16	m_iPartCount;
+        uint16  m_iED2KPartCount;
+	uint16  m_iED2KPartHashCount;
 	uint8	m_iUpPriority;
 	uint8	m_iPermissions;
 	bool	m_bAutoUpPriority;
 	uint32	m_iQueuedCount;
 	static	CBarShader s_ShareStatusBar;
+	bool	m_PublishedED2K;
 
+public:
+	time_t	m_nCompleteSourcesTime;
+	uint16	m_nCompleteSourcesCount;
+	uint16	m_nCompleteSourcesCountLo;
+	uint16	m_nCompleteSourcesCountHi;
 	CTypedPtrList<CPtrList, CUpDownClient*> m_ClientUploadList;
-	CArray<uint16,uint16> m_AvailPartFrequency;
+	CArray<uint16,uint16> 	m_AvailPartFrequency;
+	CArray<uint16,uint16>	m_PartSentCount;//added by sivka (Slugfiller: hideOS)
 };
 
 // permission values for shared files
