@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -19,23 +23,22 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
-#	include "wintypes.h"
-#	include "KnownFileList.h"
 #	include "KnownFile.h"
+#	include "KnownFileList.h"
+#	include "SafeFile.h"
+#	include "wintypes.h"
 #	include "xmule.h"
 #endif
 
 #include <wx/utils.h>
 
-static wxString KnownFileHash(const char* filename, uint32 date, uint32 size)
-{
+static wxString KnownFileHash(const char* filename, uint32 date, uint32 size) {
 	return wxString::Format("%s%08lx%08lx", filename, date, size);
 }
 
-static wxString KnownFileHash(CKnownFile *file)
-{
+static wxString KnownFileHash(CKnownFile *file) {
 	return KnownFileHash(file->GetFileName(), file->GetFileDate(),
-	                     file->GetFileSize());
+	file->GetFileSize());
 }
 
 CKnownFileList::CKnownFileList(char* in_appdir) {
@@ -47,23 +50,23 @@ CKnownFileList::CKnownFileList(char* in_appdir) {
 }
 
 CKnownFileList::~CKnownFileList() {
-// TODO: Rather find the source of the lock leakage
-//	list_mut.Unlock();
+	// TODO: Rather find the source of the lock leakage
+	//	list_mut.Unlock();
 	Clear();
 }
 
 bool CKnownFileList::Init() {
-	CKnownFile* Record = 0; 
+	CKnownFile* Record = 0;
 	CSafeFile file;
-	/*try*/ {
+    /*try*/ {
 		char* fullpath = new char[strlen(appdir)+10];
 		strcpy(fullpath,appdir);
 		strcat(fullpath,"known.met");
-		if (!wxFileExists(fullpath)) {//CFile::modeRead|CFile::osSequentialScan)) {
+		if (!wxFileExists(fullpath)) {
+			//CFile::modeRead|CFile::osSequentialScan)) {
 			delete[] fullpath;
 			return false;
 		}
-		
 		uint8 header;
 		file.Open(fullpath);
 		delete[] fullpath; fullpath = NULL;
@@ -77,10 +80,10 @@ bool CKnownFileList::Init() {
 		uint32 RecordsNumber;
 		file.Read(&RecordsNumber,4);
 		for (uint32 i = 0; i != RecordsNumber; i++) {
-			Record =  new CKnownFile();
+			Record = new CKnownFile();
 			Record->LoadFromFile(&file);
-			if ( !Append(Record) )
-				delete Record;
+			if (!Append(Record))
+			delete Record;
 		}
 		//sLock.Unlock();
 		file.Close();
@@ -89,13 +92,14 @@ bool CKnownFileList::Init() {
 #if 0
 	catch(CFileException* error) {
 		if (error->m_cause == CFileException::endOfFile)
-			theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_SERVERMET_BAD));
-		else{
+		theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_SERVERMET_BAD));
+		else {
 			char buffer[150];
 			error->GetErrorMessage(buffer,150);
 			theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_SERVERMET_UNKNOWN),buffer);
 		}
-		error->Delete();	//memleak fix
+		//memleak fix:
+		error->Delete();
 		return false;
 	}
 #endif
@@ -103,7 +107,7 @@ bool CKnownFileList::Init() {
 
 void CKnownFileList::Save() {
 	FILE* file = 0;
-	char* fullpath = new char[strlen(appdir)+MAX_PATH];
+	char* fullpath = new char[strlen(appdir)+1024];
 	strcpy(fullpath,appdir);
 	strcat(fullpath,"known.met");
 	if (!(file = fopen(fullpath, "wb"))) {
@@ -113,32 +117,32 @@ void CKnownFileList::Save() {
 	}
 	delete[] fullpath;
 	fullpath=NULL;
-
 	wxMutexLocker sLock(list_mut);
 	fputc(MET_HEADER,file);
 	uint32 RecordsNumber = m_map.size();
 	fwrite(&RecordsNumber,4,1,file);
 	KnownFileMap::iterator it = m_map.begin();
 	for (uint32 i = 0; i != RecordsNumber; i++,it++) {
-		if ( it == m_map.end() )
-			break;		// TODO: Throw an exception
+		if (it == m_map.end())
+		// TODO: Throw an exception:
+		break;
 		it->second->WriteToFile(file);
 	}
 	fclose(file);
 }
 
-void CKnownFileList::Clear() {	
+void CKnownFileList::Clear() {
 	wxMutexLocker sLock(list_mut);
-	for ( KnownFileMap::iterator it = m_map.begin(); it != m_map.end(); it++ )
-		delete it->second;
+	for (KnownFileMap::iterator it = m_map.begin(); it != m_map.end(); it++)
+	delete it->second;
 	m_map.clear();
 }
 
 CKnownFile* CKnownFileList::FindKnownFile(char* filename,uint32 in_date,uint32 in_size) {
 	wxMutexLocker sLock(list_mut);
 	KnownFileMap::iterator it = m_map.find(KnownFileHash(filename, in_date, in_size));
-	if ( it != m_map.end() )
-		return it->second;
+	if (it != m_map.end())
+	return it->second;
 	return 0;
 }
 
@@ -147,11 +151,10 @@ bool CKnownFileList::SafeAddKFile(CKnownFile* toadd) {
 	return Append(toadd);
 }
 
-bool CKnownFileList::Append(CKnownFile* Record)
-{
+bool CKnownFileList::Append(CKnownFile* Record) {
 	wxString HashString = KnownFileHash(Record);
 	KnownFileMap::iterator it = m_map.find(HashString);
-	if ( it == m_map.end() ) {
+	if (it == m_map.end()) {
 		m_map[HashString] = Record;
 		return true;
 	} else {
@@ -159,3 +162,5 @@ bool CKnownFileList::Append(CKnownFile* Record)
 	}
 }
 
+
+
