@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -76,9 +80,11 @@ public:
 
 	bool		Create();
 	void		OnClose(int nErrorCode);
-	void		OnSend(int nErrorCode);
-	void		OnReceive(int nErrorCode);
-	void		OnError(int nErrorCode);
+
+	void		OnLost(int nErrorCode);
+	void		OnInput(int nErrorCode);
+	void		OnOutput(int nErrorCode);
+
 	virtual	void OnInit();
 	virtual	bool Close(); /*	{return wxSocketBase::Close();}*/
 	
