@@ -204,25 +204,6 @@ void CPPgGeneral::OnApply() {
 		buffer=GetDlgItem(IDC_NICK,wxTextCtrl)->GetValue();
 		strcpy(app_prefs->prefs->nick,buffer);
 	}
-#if 0
-	// we support no languages yet!
-	if (m_language.GetCurSel() != CB_ERR) {
-		WORD byNewLang = m_language.GetItemData(m_language.GetCurSel());
-		if (app_prefs->prefs->languageID != byNewLang) {
-			app_prefs->prefs->languageID= byNewLang;
-			theApp.glob_prefs->SetLanguage();
-			theApp.xmuledlg->preferenceswnd.Localize();
-			theApp.xmuledlg->statisticswnd.Localize();
-			theApp.xmuledlg->serverwnd.Localize();
-			theApp.xmuledlg->transferwnd.Localize();
-			theApp.xmuledlg->searchwnd.Localize();
-			theApp.xmuledlg->sharedfileswnd.Localize();
-			theApp.xmuledlg->chatwnd.Localize();
-			theApp.xmuledlg->Localize();
-			theApp.xmuledlg->ircwnd.Localize();
-		}
-	}
-#endif
 	int8 mintotray_old= app_prefs->prefs->mintotray;
 	app_prefs->prefs->startMinimized= (int8) IsDlgButtonChecked(IDC_STARTMIN);
 	app_prefs->prefs->mintotray = (int8) IsDlgButtonChecked(IDC_MINTRAY);
@@ -240,29 +221,14 @@ void CPPgGeneral::OnApply() {
 	app_prefs->prefs->m_iToolDelayTime = 32;
 	else
 	app_prefs->prefs->m_iToolDelayTime = atoi(buffer);
-#if 0
-	((CxmuleDlg*) AfxGetMainWnd())->transferwnd.m_ttip.SetDelayTime(TTDT_INITIAL, theApp.glob_prefs->GetToolTipDelay() *1000);
-#endif
 	// no setstyle as we can't do that anyway
 	//theApp.xmuledlg->transferwnd->downloadlistctrl->SetStyle();
 	//	app_prefs->Save();
 	LoadSettings();
-#if 0
-	if (mintotray_old != app_prefs->prefs->mintotray)
-	theApp.xmuledlg->TrayMinimizeToTrayChange();
-#endif
 	//SetModified(FALSE);
 	//return CPropertyPage::OnApply();
 }
 
-#if 0
-void CPPgGeneral::OnBnClickedEd2kfix() {
-	Ask4RegFix(false);
-	GetDlgItem(IDC_ED2KFIX)->EnableWindow(Ask4RegFix(true));
-}
-
-#endif
-
 void CPPgGeneral::Localize(void) {
 	if(1) {
 		//SetWindowText(GetResString(IDS_PW_GENERAL));
