@@ -1214,9 +1214,9 @@ bool CPartFile::GetNextRequestedBlock(CUpDownClient* sender,Requested_Block_Stru
 		liPossibleParts.RemoveAll();
 		// Barry - Top priority should be to continue downloading from current blocks (if anything left to download)
 		bool foundPriorityPart = false;
-		CString gettingParts;
-		sender->ShowDownloadingParts(&gettingParts);
-		for (int i=(gettingParts.GetLength()-1); i>=0; i--) {
+		wxString gettingParts;
+		sender->ShowDownloadingParts(gettingParts);
+		for (int i=(gettingParts.Len()-1); i>=0; i--) {
 			if ((gettingParts.GetChar(i) == 'Y')&& (GetNextEmptyBlockInPart(i, 0))) {
 				liGoodParts.AddHead(i);
 				foundPriorityPart = true;
