@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -23,18 +27,19 @@
 #endif
 
 CSafeFile::CSafeFile(LPCSTR lpszFileName,UINT nOpenFlags)
-:CFile(lpszFileName,(CFile::OpenMode)nOpenFlags)
+:CFile(lpszFileName,(CFile::OpenMode) nOpenFlags)
 //:CFile(lpszFileName,nOpenFlags)
 {
 	// Nothing to do here
 }
 
-CSafeFile::CSafeFile() : CFile() {}
+CSafeFile::CSafeFile() : CFile() {
+}
 
 
 UINT CSafeFile::Read(void* lpBuf,UINT nCount) {
 	if (Tell()+nCount > Length()) {
-//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
+		//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
 		return (UINT)-1;
 	}
 	return CFile::Read(lpBuf,nCount);
@@ -42,17 +47,19 @@ UINT CSafeFile::Read(void* lpBuf,UINT nCount) {
 
 
 CSafeMemFile::CSafeMemFile(BYTE* lpBuffer,UINT nBufferSize,UINT nGrowBytes)
-:CMemFile(lpBuffer,nBufferSize,nGrowBytes)
-{
+:CMemFile(lpBuffer,nBufferSize,nGrowBytes) {
 	// Nothing to do here
 }
 
-CSafeMemFile::CSafeMemFile(UINT nGrowBytes) : CMemFile(nGrowBytes) {}
+CSafeMemFile::CSafeMemFile(UINT nGrowBytes) : CMemFile(nGrowBytes) {
+}
 
 UINT CSafeMemFile::Read(void* lpBuf,UINT nCount) {
 	if (GetPosition()+nCount > this->GetLength()) {
-//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
+		//		AfxThrowFileException(CFileException::endOfFile,0,GetFileName());
 		return 0;
 	}
 	return CMemFile::Read(lpBuf,nCount);
 }
+
+
