@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -34,34 +38,32 @@
 #define GetDlgItem(X) (wxStaticCast(wxWindow::FindWindowById((X)),wxStaticText))
 
 BEGIN_EVENT_TABLE(CSharedFilesWnd,wxPanel)
-  EVT_LIST_ITEM_SELECTED(ID_SHFILELIST,CSharedFilesWnd::OnLvnItemActivateSflist)
-  EVT_BUTTON(IDC_RELOADSHAREDFILES, CSharedFilesWnd::OnBnClickedReloadsharedfiles)
+EVT_LIST_ITEM_SELECTED(ID_SHFILELIST,CSharedFilesWnd::OnLvnItemActivateSflist)
+EVT_BUTTON(IDC_RELOADSHAREDFILES, CSharedFilesWnd::OnBnClickedReloadsharedfiles)
 END_EVENT_TABLE()
 
 //IMPLEMENT_DYNAMIC(CSharedFilesWnd, CDialog)
-CSharedFilesWnd::CSharedFilesWnd(wxWindow* pParent /*=NULL*/)
-	: wxPanel(pParent,CSharedFilesWnd::IDD)
-{
-  memset(shownFileHash,0,sizeof shownFileHash);
-  SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWFRAME));
-  wxSizer* content=sharedfilesDlg(this,TRUE);
-  content->Show(this,TRUE);
+    CSharedFilesWnd::CSharedFilesWnd(wxWindow* pParent /*=NULL*/
 
-  pop_bar=(wxGauge*)FindWindowByName("popbar");
-  pop_baraccept=(wxGauge*)FindWindowByName("popbarAccept");
-  pop_bartrans=(wxGauge*)FindWindowByName("popbarTrans");
-
-  // can't do here. 
-  //theApp.sharedfiles->SetOutputCtrl((CSharedFilesCtrl*)FindWindowByName("sharedFilesCt"));
-  sharedfilesctrl=(CSharedFilesCtrl*)(FindWindowByName("sharedFilesCt"));
+)
+: wxPanel(pParent,CSharedFilesWnd::IDD) {
+	memset(shownFileHash,0,sizeof shownFileHash);
+	SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWFRAME));
+	wxSizer* content=sharedfilesDlg(this,TRUE);
+	content->Show(this,TRUE);
+	pop_bar=(wxGauge*) FindWindowByName("popbar");
+	pop_baraccept=(wxGauge*) FindWindowByName("popbarAccept");
+	pop_bartrans=(wxGauge*) FindWindowByName("popbarTrans");
+	// can't do here.
+	//theApp.sharedfiles->SetOutputCtrl((CSharedFilesCtrl*)FindWindowByName("sharedFilesCt"));
+	sharedfilesctrl=(CSharedFilesCtrl*) (FindWindowByName("sharedFilesCt"));
 }
 
-CSharedFilesWnd::~CSharedFilesWnd()
-{
+CSharedFilesWnd::~CSharedFilesWnd() {
 }
 
 #if 0
-void CSharedFilesWnd::DoDataExchange(CDataExchange* pDX){
+void CSharedFilesWnd::DoDataExchange(CDataExchange* pDX) {
 	CResizableDialog::DoDataExchange(pDX);
 	DDX_Control(pDX, IDC_SFLIST, sharedfilesctrl);
 	DDX_Control(pDX, IDC_POPBAR, pop_bar);
@@ -69,24 +71,22 @@ void CSharedFilesWnd::DoDataExchange(CDataExchange* pDX){
 	DDX_Control(pDX, IDC_POPBAR3, pop_bartrans);
 	DDX_Control(pDX, IDC_STATISTICS, m_ctrlStatisticsFrm);
 }
+
 #endif
 
 #if 0
-BOOL CSharedFilesWnd::OnInitDialog(){
+BOOL CSharedFilesWnd::OnInitDialog() {
 	CResizableDialog::OnInitDialog();
 	Localize();
 	sharedfilesctrl.Init();
 	theApp.sharedfiles->SetOutputCtrl(&sharedfilesctrl);
-	
 	pop_bar.SetGradientColors(RGB(255,255,240),RGB(255,255,0));
 	pop_bar.SetTextColor(RGB(20,70,255));
 	pop_baraccept.SetGradientColors(RGB(255,255,240),RGB(255,255,0));
 	pop_baraccept.SetTextColor(RGB(20,70,255));
 	pop_bartrans.SetGradientColors(RGB(255,255,240),RGB(255,255,0));
 	pop_bartrans.SetTextColor(RGB(20,70,255));
-	
-	((CStatic*)GetDlgItem(IDC_FILES_ICO))->SetIcon((HICON)::LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_SHAREDFILES), IMAGE_ICON, 16, 16, 0));
-	
+	((CStatic*) GetDlgItem(IDC_FILES_ICO))->SetIcon((HICON) ::LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_SHAREDFILES), IMAGE_ICON, 16, 16, 0));
 	LOGFONT lf;
 	GetFont()->GetLogFont(&lf);
 	lf.lfWeight = FW_BOLD;
@@ -95,7 +95,6 @@ BOOL CSharedFilesWnd::OnInitDialog(){
 	m_ctrlStatisticsFrm.Init(IDI_SMALLSTATISTICS);
 	GetDlgItem(IDC_CURSESSION_LBL)->SetFont(&bold);
 	GetDlgItem(IDC_TOTAL_LBL)->SetFont(&bold);
-	
 	AddAnchor(IDC_FILES_ICO, TOP_LEFT);
 	AddAnchor(IDC_TRAFFIC_TEXT, TOP_LEFT);
 	AddAnchor(IDC_SFLIST,TOP_LEFT,BOTTOM_RIGHT);
@@ -118,42 +117,38 @@ BOOL CSharedFilesWnd::OnInitDialog(){
 	AddAnchor(IDC_POPBAR3,BOTTOM_LEFT);
 	AddAnchor(IDC_FSTATIC9,BOTTOM_LEFT);
 	AddAnchor(IDC_STRANSFERED2,BOTTOM_LEFT);
-	
 	return true;
 }
 
 BEGIN_MESSAGE_MAP(CSharedFilesWnd, CResizableDialog)
-	ON_BN_CLICKED(IDC_RELOADSHAREDFILES, OnBnClickedReloadsharedfiles)
-	ON_NOTIFY(LVN_ITEMACTIVATE, IDC_SFLIST, OnLvnItemActivateSflist)
-	ON_NOTIFY(NM_CLICK, IDC_SFLIST, OnNMClickSflist)
+ON_BN_CLICKED(IDC_RELOADSHAREDFILES, OnBnClickedReloadsharedfiles)
+ON_NOTIFY(LVN_ITEMACTIVATE, IDC_SFLIST, OnLvnItemActivateSflist)
+ON_NOTIFY(NM_CLICK, IDC_SFLIST, OnNMClickSflist)
 END_MESSAGE_MAP()
 #endif
 
 // CSharedFilesWnd message handlers
-void CSharedFilesWnd::OnBnClickedReloadsharedfiles()
-{
+void CSharedFilesWnd::OnBnClickedReloadsharedfiles() {
 	theApp.sharedfiles->Reload(true, false);
 }
 
 #if 0
-void CSharedFilesWnd::Check4StatUpdate(CKnownFile* file){
-	if (!memcmp(file->GetFileHash(),shownFileHash ,16)) ShowDetails(file);
+void CSharedFilesWnd::Check4StatUpdate(CKnownFile* file) {
+	if (!memcmp(file->GetFileHash(),shownFileHash,16)) ShowDetails(file);
 }
+
 #endif
 
-void CSharedFilesWnd::Check4StatUpdate(CKnownFile* file){
-	if (!memcmp(file->GetFileHash(),shownFileHash ,16)) ShowDetails(file);
+void CSharedFilesWnd::Check4StatUpdate(CKnownFile* file) {
+	if (!memcmp(file->GetFileHash(),shownFileHash,16)) ShowDetails(file);
 }
 
-void CSharedFilesWnd::OnLvnItemActivateSflist(wxListEvent& evt)
-{
-  long item=-1;
-  wxODListCtrl* sflist=wxStaticCast(FindWindowById(ID_SHFILELIST),wxODListCtrl);
-  item=sflist->GetNextItem(item,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
-
-	if (item != (-1) ) {
-		CKnownFile* cur_file = (CKnownFile*)sflist->GetItemData(item);
-
+void CSharedFilesWnd::OnLvnItemActivateSflist(wxListEvent& evt) {
+	long item=-1;
+	wxODListCtrl* sflist=wxStaticCast(FindWindowById(ID_SHFILELIST),wxODListCtrl);
+	item=sflist->GetNextItem(item,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
+	if (item != (-1)) {
+		CKnownFile* cur_file = (CKnownFile*) sflist->GetItemData(item);
 		ShowDetails(cur_file);
 	}
 }
@@ -161,57 +156,49 @@ void CSharedFilesWnd::OnLvnItemActivateSflist(wxListEvent& evt)
 
 void CSharedFilesWnd::ShowDetails(CKnownFile* cur_file) {
 	char buffer[100];
-
 	//pop_bartrans.SetRange32(0,theApp.knownfiles->transfered/1024);
 	pop_bartrans->SetRange(theApp.knownfiles->transfered/1024);
 	//pop_bartrans.SetPos(cur_file->statistic.GetTransfered()/1024);
-	pop_bartrans->SetValue(cur_file->statistic.GetTransfered()/1024);
-	//pop_bartrans.SetShowPercent();				
+	pop_bartrans->SetValue(cur_file->statistic.GetTransfered() /1024);
+	//pop_bartrans.SetShowPercent();
 	GetDlgItem(IDC_STRANSFERED)->SetLabel(CastItoXBytes(cur_file->statistic.GetTransfered()));
-
 	pop_bar->SetRange(theApp.knownfiles->requested);
 	pop_bar->SetValue(cur_file->statistic.GetRequests());
-	//pop_bar.SetShowPercent();			
+	//pop_bar.SetShowPercent();
 	sprintf(buffer,"%u",cur_file->statistic.GetRequests());
 	GetDlgItem(IDC_SREQUESTED)->SetLabel(buffer);
-
 	sprintf(buffer,"%u",cur_file->statistic.GetAccepts());
 	pop_baraccept->SetRange(theApp.knownfiles->accepted);
 	pop_baraccept->SetValue(cur_file->statistic.GetAccepts());
 	//pop_baraccept.SetShowPercent();
 	GetDlgItem(IDC_SACCEPTED)->SetLabel(buffer);
-	
 	GetDlgItem(IDC_STRANSFERED2)->SetLabel(CastItoXBytes(cur_file->statistic.GetAllTimeTransfered()));
-
 	sprintf(buffer,"%u",cur_file->statistic.GetAllTimeRequests());
 	GetDlgItem(IDC_SREQUESTED2)->SetLabel(buffer);
-
 	sprintf(buffer,"%u",cur_file->statistic.GetAllTimeAccepts());
 	GetDlgItem(IDC_SACCEPTED2)->SetLabel(buffer);
-
 	memcpy(shownFileHash,cur_file->GetFileHash(),16);
-
 	//CString title=GetResString(IDS_SF_STATISTICS)+" ("+ cur_file->GetFileName() +")";
 	//GetDlgItem(IDC_FSTATIC1)->SetWindowText( title );
 }
 
 #if 0
-void CSharedFilesWnd::OnNMClickSflist(NMHDR *pNMHDR, LRESULT *pResult){
+void CSharedFilesWnd::OnNMClickSflist(NMHDR *pNMHDR, LRESULT *pResult) {
 	OnLvnItemActivateSflist(pNMHDR,pResult);
 	*pResult = 0;
 }
 
-BOOL CSharedFilesWnd::PreTranslateMessage(MSG* pMsg) 
-{
-   if((pMsg->message == WM_KEYUP)){
-	   if (pMsg->hwnd == GetDlgItem(IDC_SFLIST)->m_hWnd)
-			OnLvnItemActivateSflist(0,0);
-   }
-   return CResizableDialog::PreTranslateMessage(pMsg);
+BOOL CSharedFilesWnd::PreTranslateMessage(MSG* pMsg) {
+	if((pMsg->message == WM_KEYUP)) {
+		if (pMsg->hwnd == GetDlgItem(IDC_SFLIST)->m_hWnd)
+		OnLvnItemActivateSflist(0,0);
+	}
+	return CResizableDialog::PreTranslateMessage(pMsg);
 }
+
 #endif
 
-void CSharedFilesWnd::Localize(){
+void CSharedFilesWnd::Localize() {
 #if 0
 	sharedfilesctrl.Localize();
 	GetDlgItem(IDC_TRAFFIC_TEXT)->SetWindowText(GetResString(IDS_SF_FILES));
@@ -227,3 +214,5 @@ void CSharedFilesWnd::Localize(){
 	GetDlgItem(IDC_FSTATIC7)->SetWindowText(GetResString(IDS_SF_REQUESTED));
 #endif
 }
+
+
