@@ -1,3 +1,21 @@
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //{{NO_DEPENDENCIES}}
 // Microsoft Visual C++ generated include file.
 // Used by xmule.rc
@@ -1735,6 +1753,8 @@
 #define IDS_SWAP_A4AF_TO_ANY_OTHER           5727
 #define IDS_EXTENDED                         5728
 /* End modif */
+
+#define ID_SOKETTI 7772
   
 #define IDD_PPG_SOURCES_DROPPING 12743
 #define IDD_PPG_GUI_TWEAKS 12744
