@@ -1,5 +1,27 @@
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+//
+//This program is free software; you can redistribute it and/or
+//modify it under the terms of the GNU General Public License
+//as published by the Free Software Foundation; either
+//version 2 of the License, or (at your option) any later version.
+//
+//This program is distributed in the hope that it will be useful,
+//but WITHOUT ANY WARRANTY; without even the implied warranty of
+//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//GNU General Public License for more details.
+//
+//You should have received a copy of the GNU General Public License
+//along with this program; if not, write to the Free Software
+//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 #ifndef _xmule_headers_h
 #define _xmule_headers_h
+#include "syspch.h"
 #include "resource.h"
 #include "AddFileThread.h"
 #include "AddFriend.h"
@@ -28,7 +50,6 @@
 #include "FriendList.h"
 #include "FriendListCtrl.h"
 #include "HTTPDownloadDlg.h"
-//#include "HashThread.h"
 #include "IPFilter.h"
 #include "KnownFile.h"
 #include "KnownFileList.h"
@@ -59,9 +80,7 @@
 #include "SafeFile.h"
 #include "SearchDlg.h"
 #include "SearchList.h"
-#include "SearchListCtrl.h"
 #include "ServerList.h"
-#include "ServerListCtrl.h"
 #include "ServerSocket.h"
 #include "ServerWnd.h"
 #include "SharedFileList.h"
@@ -69,7 +88,7 @@
 #include "SharedFilesWnd.h"
 #include "SplitterControl.h"
 #include "StatisticsDlg.h"
-//#include "SysTray.h" -- Fix this!!  I'm too lazy atm :-))
+#include "SysTray.h"
 #include "TabCtrl.h"
 #include "TransferWnd.h"
 #include "UDPSocket.h"
