@@ -62,6 +62,7 @@
 #include <wx/splash.h>
 #include <wx/toolbar.h>
 #include <wx/utils.h>
+#include <wx/radiobut.h>
 
 #include "pixmaps/mule_TrayIcon.ico.xpm"
 #include "pixmaps/mule_Tr_yellow.ico.xpm"
@@ -92,6 +93,8 @@
 #define ID_UQTIMER 59742
 #define TM_DNSDONE 17851
 
+extern wxRadioButton *radiobutton[4];
+
 BEGIN_EVENT_TABLE(CxmuleDlg,wxFrame)
 EVT_SOCKET(ID_SOKETTI, CxmuleDlg::socketHandler)
 EVT_TOOL(ID_BUTTONSERVERS,CxmuleDlg::btnServers)
@@ -328,16 +331,19 @@ void CxmuleDlg::changeDesktopMode() {
 	query.ShowModal();
 	// then determine what choice is selected
 	int mode=0;
-	if(wxStaticCast(query.FindWindowById(ID_GNOME2),wxRadioButton)->GetValue()) {
+printf("changeDesktopMode1\n");
+	if(radiobutton[0]->GetValue()) {
 		mode=1;
-	} else if(wxStaticCast(query.FindWindowById(ID_KDE3),wxRadioButton)->GetValue()) {
+	} else if(radiobutton[1]->GetValue()) {
 		mode=2;
-	} else if(wxStaticCast(query.FindWindowById(ID_KDE2),wxRadioButton)->GetValue()) {
+	} else if(radiobutton[2]->GetValue()) {
 		mode=3;
 	} else {
 		mode=4;
 	}
+printf("changeDesktopMode5\n");
 	theApp.glob_prefs->SetDesktopMode(mode);
+printf("changeDesktopMode6\n");
 }
 
 void CxmuleDlg::createSystray(const wxString& title) {
