@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -21,9 +25,7 @@
 #ifndef EMULEDLG_H
 #define EMULEDLG_H
 
-#include "sockets.h"
-//#include "afxcmn.h"
-//#include "afxwin.h"
+/*#include "sockets.h"
 #include "ServerListCtrl.h"
 #include "KnownFileList.h"
 #include "TransferWnd.h"
@@ -32,14 +34,25 @@
 #include "SharedFilesWnd.h"
 #include "SearchDlg.h"
 #include "ChatWnd.h"
-//#include "TrayDialog.h"
-//#include "BtnST.h"
 #include "StatisticsDlg.h"
-//#include "MeterIcon.h"
-//#include "IrcWnd.h"
-//#include "TaskbarNotifier.h"
-#include "SysTray.h"
-#include <wx/toolbar.h>
+#include "SysTray.h"*/
+#include "resource.h"
+#include "types.h"
+
+class CTransferWnd;
+class CServerWnd;
+class CPreferencesDlg;
+class CSharedFilesWnd;
+class CSearchDlg;
+class CChatWnd;
+class CStatisticsDlg;
+class CSysTray;
+
+class wxMenu;
+class wxSocketEvent;
+class wxTimerEvent;
+
+#include <wx/imaglist.h>
 
 enum APPState {APP_STATE_RUNNING=0,
 	       APP_STATE_SHUTINGDOWN,
@@ -52,10 +65,9 @@ enum APPState {APP_STATE_RUNNING=0,
 #define MP_DISCONNECT	4003
 #define MP_EXIT			4004
 
-#include "wx/dialog.h"
-#include "wx/statusbr.h"
-#include "wx/button.h"
-#include "wx/frame.h"
+#include <wx/button.h>
+#include <wx/frame.h>
+#include <wx/toolbar.h>
 
 class CKnownFileList; 
 // CxmuleDlg Dialogfeld
@@ -90,19 +102,14 @@ public:
 	void createSystray(const wxString& title);
 	void changeDesktopMode();
 
-	CTransferWnd*	transferwnd;
-	CServerWnd*		serverwnd;
-	CPreferencesDlg* preferenceswnd;
-	//CPreferencesDlg	preferenceswnd;
-	CSharedFilesWnd*	sharedfileswnd;
-	CSearchDlg*		searchwnd;
-	CChatWnd*		chatwnd;
-	wxStatusBar  statusbar;
-	//wxDialog*		activewnd;
-	wxWindow* activewnd;
-	CStatisticsDlg*  statisticswnd;
-	//CIrcWnd			ircwnd;
-	//CTaskbarNotifier m_wndTaskbarNotifier;
+	CTransferWnd *transferwnd;
+	CServerWnd *serverwnd;
+	CPreferencesDlg *preferenceswnd;
+	CSharedFilesWnd *sharedfileswnd;
+	CSearchDlg *searchwnd;
+	CChatWnd *chatwnd;
+	wxWindow *activewnd;
+	CStatisticsDlg *statisticswnd;
 	CSysTray *m_wndTaskbarNotifier;
 	volatile APPState		m_app_state;	// added volatile to get some more security when accessing this as a shared object...
 	uint8			status;
@@ -185,7 +192,7 @@ private:
 	uint32			lastuprate;
 	uint32			lastdownrate;
 	wxImageList		imagelist;
-	wxMenu		trayPopup;
+	wxMenu		*trayPopup;
 
 	wxButton	m_btnConnect;
 	wxButton	m_btnDownloads;
